#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mustache
version:              2.3.1
visibility:           public
id:                   mustache-2.3.1-D7tfUCU7Rux3bdqwvVc4b3
key:                  mustache-2.3.1-D7tfUCU7Rux3bdqwvVc4b3
license:              BSD-3-Clause
copyright:            (c) 2015 - 2019 Justus Adam
maintainer:           dev@justus.science
author:               Justus Adam
homepage:             https://github.com/JustusAdam/mustache
synopsis:             A mustache template parser library.
description:
    Allows parsing and rendering template files with mustache markup. See the
    mustache <http://mustache.github.io/mustache.5.html language reference>.

    Implements the mustache spec version 1.1.3.

    /Note/: Versions including and beyond 0.4 are compatible with ghc 7.8 again.

category:             Development
abi:                  e0630910ee1d60d694aef1b704e4e1da
exposed:              True
exposed-modules:
    Text.Mustache Text.Mustache.Compile Text.Mustache.Parser
    Text.Mustache.Render Text.Mustache.Types

hidden-modules:
    Text.Mustache.Internal Text.Mustache.Internal.Types Paths_mustache

import-dirs:          /usr/lib/ghc-8.10.5/site-local/mustache-2.3.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mustache-2.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mustache-2.3.1
hs-libraries:         HSmustache-2.3.1-D7tfUCU7Rux3bdqwvVc4b3
depends:
    aeson-1.5.6.0-Fw6cTmCp4oOK2plDv84u6I base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1 directory-1.3.6.0
    either-5.0.1.1-JbWXejYwX4zIjVYzle5w4e filepath-1.4.2.1 mtl-2.2.2
    parsec-3.1.14.0 scientific-0.3.7.0-VQu2zXXWCs7DIf6RrgM53
    template-haskell-2.16.0.0 text-1.2.4.1
    th-lift-0.8.2-A94jWiBJfaQF1v2Vq9YgsH
    unordered-containers-0.2.14.0-Dm8JoFpaxnRD1kEXsRDdDL
    vector-0.12.3.0-K9OZS5OCy7cE2QKQqSO9mp

haddock-interfaces:   /usr/share/doc/haskell-mustache/html/mustache.haddock
haddock-html:         /usr/share/doc/haskell-mustache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

